CHARSET_RAM = 0x3000
CHARSET_ROM = 0x1000
COLOR_ROM = 0xD800
DEFAULT_BUFFER = 0xC000
KERNEL_CINT = 0xFF81
SCREEN_RAM = 0x0400
SCREEN_RAM2 = 0x2000
VICII_BASE = 0xD000
VICII_BGCOLOR = 0x21
VICII_BRCOLOR = 0x20
VICII_MEMPTRS = 0x18
VICII_VERTCONTROL = 0x11
COLS = 40
ROWS = 25
SCREEN_SIZE = COLS * ROWS

